@@ -125,6 +125,8 @@ CONTAINERS_TASK_FIELD = 'containersTask'
 CONTAINERS_FIELD = 'containers'
 ENV_FIELD = 'env'
 LABELS_FIELD = 'labels'
+DEPLOY_FIELD = 'deploy'
+RENDER_FIELD = 'render'
 
 
 def ParseDeployConfig(messages, manifests, region):
@@ -287,6 +289,9 @@ def _ParseV1Config(messages, kind, manifest, project, region, resource_dict):
       if field == 'customTarget' and kind == TARGET_KIND_V1BETA1:
         SetCustomTarget(resource, value, project, region)
         continue
+      if field == TASKS_FIELD and kind == CUSTOM_TARGET_TYPE_KIND:
+        SetCustomTargetTasks(messages, resource, value)
+        continue
       if field == 'associatedEntities' and kind == TARGET_KIND_V1BETA1:
         SetAssociatedEntities(messages, resource, resource_ref, value)
         continue
@@ -434,6 +439,8 @@ def SetEnvForTask(messages, task):
   # map into an EnvValue message.
   if task.get(CONFIG_TASK_FIELD):
     config_task = task.get(CONFIG_TASK_FIELD)
+    if not config_task.get(ENV_FIELD):
+      return
     config_task_message = getattr(messages, 'ConfigTask')
     env_message = config_task_message.EnvValue
     env_dict = env_message()
@@ -445,6 +452,8 @@ def SetEnvForTask(messages, task):
   elif task.get(CONTAINERS_TASK_FIELD):
     containers_task = task.get(CONTAINERS_TASK_FIELD)
     for container in containers_task.get(CONTAINERS_FIELD):
+      if not container.get(ENV_FIELD):
+        continue
       container_message = getattr(messages, 'Container')
       env_message = container_message.EnvValue
       env_dict = env_message()
@@ -1073,6 +1082,27 @@ def SetCustomTarget(target, custom_target, project, region):
   target.customTarget = custom_target
 
 
+def SetCustomTargetTasks(messages, custom_target_type, tasks):
+  """Sets the tasks field of cloud deploy custom target type message.
+
+  This is handled specially because we allow providing either the ID or name for
+  the custom target type referenced. When the ID is provided we need to
+  construct the name.
+
+  Args:
+    messages: module containing the definitions of messages for Cloud Deploy.
+    custom_target_type: custom target type resource.
+    tasks: googlecloudsdk.generated_clients.apis.clouddeploy.CustomTargetTasks
+      message.
+  """
+  # Set any env variables defined on CustomTargetTasks.
+  if tasks.get(DEPLOY_FIELD):
+    SetEnvForTask(messages, tasks.get(DEPLOY_FIELD))
+  if tasks.get(RENDER_FIELD):
+    SetEnvForTask(messages, tasks.get(RENDER_FIELD))
+  custom_target_type.tasks = tasks
+
+
 def SetAutomationSelector(messages, automation, selectors):
   """Sets the selectors field of cloud deploy automation resource message.
 
